user

package
v0.0.0-...-d470ab9 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 10, 2024 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the user type in the database.
	Label = "user"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldUsername holds the string denoting the username field in the database.
	FieldUsername = "username"
	// FieldEmail holds the string denoting the email field in the database.
	FieldEmail = "email"
	// FieldAvatar holds the string denoting the avatar field in the database.
	FieldAvatar = "avatar"
	// FieldBirthDay holds the string denoting the birth_day field in the database.
	FieldBirthDay = "birth_day"
	// FieldFirstName holds the string denoting the first_name field in the database.
	FieldFirstName = "first_name"
	// FieldLastName holds the string denoting the last_name field in the database.
	FieldLastName = "last_name"
	// FieldPhoneNumber holds the string denoting the phone_number field in the database.
	FieldPhoneNumber = "phone_number"
	// FieldGender holds the string denoting the gender field in the database.
	FieldGender = "gender"
	// FieldStatus holds the string denoting the status field in the database.
	FieldStatus = "status"
	// FieldAddress holds the string denoting the address field in the database.
	FieldAddress = "address"
	// FieldStreet holds the string denoting the street field in the database.
	FieldStreet = "street"
	// FieldDistrictID holds the string denoting the district_id field in the database.
	FieldDistrictID = "district_id"
	// FieldCityID holds the string denoting the city_id field in the database.
	FieldCityID = "city_id"
	// FieldCountryCode holds the string denoting the country_code field in the database.
	FieldCountryCode = "country_code"
	// FieldHashPassword holds the string denoting the hash_password field in the database.
	FieldHashPassword = "hash_password"
	// FieldVerified holds the string denoting the verified field in the database.
	FieldVerified = "verified"
	// FieldCreatedAt holds the string denoting the created_at field in the database.
	FieldCreatedAt = "created_at"
	// FieldUpdatedAt holds the string denoting the updated_at field in the database.
	FieldUpdatedAt = "updated_at"
	// Table holds the table name of the user in the database.
	Table = "users"
)

Variables

var (
	// UsernameValidator is a validator for the "username" field. It is called by the builders before save.
	UsernameValidator func(string) error
	// EmailValidator is a validator for the "email" field. It is called by the builders before save.
	EmailValidator func(string) error
	// HashPasswordValidator is a validator for the "hash_password" field. It is called by the builders before save.
	HashPasswordValidator func(string) error
	// DefaultVerified holds the default value on creation for the "verified" field.
	DefaultVerified bool
	// DefaultCreatedAt holds the default value on creation for the "created_at" field.
	DefaultCreatedAt func() time.Time
	// DefaultUpdatedAt holds the default value on creation for the "updated_at" field.
	DefaultUpdatedAt func() time.Time
	// UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field.
	UpdateDefaultUpdatedAt func() time.Time
	// DefaultID holds the default value on creation for the "id" field.
	DefaultID func() uuid.UUID
)

Columns holds all SQL columns for user fields.

Functions

func Address

func Address(v string) predicate.User

Address applies equality check predicate on the "address" field. It's identical to AddressEQ.

func AddressContains

func AddressContains(v string) predicate.User

AddressContains applies the Contains predicate on the "address" field.

func AddressContainsFold

func AddressContainsFold(v string) predicate.User

AddressContainsFold applies the ContainsFold predicate on the "address" field.

func AddressEQ

func AddressEQ(v string) predicate.User

AddressEQ applies the EQ predicate on the "address" field.

func AddressEqualFold

func AddressEqualFold(v string) predicate.User

AddressEqualFold applies the EqualFold predicate on the "address" field.

func AddressGT

func AddressGT(v string) predicate.User

AddressGT applies the GT predicate on the "address" field.

func AddressGTE

func AddressGTE(v string) predicate.User

AddressGTE applies the GTE predicate on the "address" field.

func AddressHasPrefix

func AddressHasPrefix(v string) predicate.User

AddressHasPrefix applies the HasPrefix predicate on the "address" field.

func AddressHasSuffix

func AddressHasSuffix(v string) predicate.User

AddressHasSuffix applies the HasSuffix predicate on the "address" field.

func AddressIn

func AddressIn(vs ...string) predicate.User

AddressIn applies the In predicate on the "address" field.

func AddressIsNil

func AddressIsNil() predicate.User

AddressIsNil applies the IsNil predicate on the "address" field.

func AddressLT

func AddressLT(v string) predicate.User

AddressLT applies the LT predicate on the "address" field.

func AddressLTE

func AddressLTE(v string) predicate.User

AddressLTE applies the LTE predicate on the "address" field.

func AddressNEQ

func AddressNEQ(v string) predicate.User

AddressNEQ applies the NEQ predicate on the "address" field.

func AddressNotIn

func AddressNotIn(vs ...string) predicate.User

AddressNotIn applies the NotIn predicate on the "address" field.

func AddressNotNil

func AddressNotNil() predicate.User

AddressNotNil applies the NotNil predicate on the "address" field.

func And

func And(predicates ...predicate.User) predicate.User

And groups predicates with the AND operator between them.

func Avatar

func Avatar(v string) predicate.User

Avatar applies equality check predicate on the "avatar" field. It's identical to AvatarEQ.

func AvatarContains

func AvatarContains(v string) predicate.User

AvatarContains applies the Contains predicate on the "avatar" field.

func AvatarContainsFold

func AvatarContainsFold(v string) predicate.User

AvatarContainsFold applies the ContainsFold predicate on the "avatar" field.

func AvatarEQ

func AvatarEQ(v string) predicate.User

AvatarEQ applies the EQ predicate on the "avatar" field.

func AvatarEqualFold

func AvatarEqualFold(v string) predicate.User

AvatarEqualFold applies the EqualFold predicate on the "avatar" field.

func AvatarGT

func AvatarGT(v string) predicate.User

AvatarGT applies the GT predicate on the "avatar" field.

func AvatarGTE

func AvatarGTE(v string) predicate.User

AvatarGTE applies the GTE predicate on the "avatar" field.

func AvatarHasPrefix

func AvatarHasPrefix(v string) predicate.User

AvatarHasPrefix applies the HasPrefix predicate on the "avatar" field.

func AvatarHasSuffix

func AvatarHasSuffix(v string) predicate.User

AvatarHasSuffix applies the HasSuffix predicate on the "avatar" field.

func AvatarIn

func AvatarIn(vs ...string) predicate.User

AvatarIn applies the In predicate on the "avatar" field.

func AvatarIsNil

func AvatarIsNil() predicate.User

AvatarIsNil applies the IsNil predicate on the "avatar" field.

func AvatarLT

func AvatarLT(v string) predicate.User

AvatarLT applies the LT predicate on the "avatar" field.

func AvatarLTE

func AvatarLTE(v string) predicate.User

AvatarLTE applies the LTE predicate on the "avatar" field.

func AvatarNEQ

func AvatarNEQ(v string) predicate.User

AvatarNEQ applies the NEQ predicate on the "avatar" field.

func AvatarNotIn

func AvatarNotIn(vs ...string) predicate.User

AvatarNotIn applies the NotIn predicate on the "avatar" field.

func AvatarNotNil

func AvatarNotNil() predicate.User

AvatarNotNil applies the NotNil predicate on the "avatar" field.

func BirthDay

func BirthDay(v string) predicate.User

BirthDay applies equality check predicate on the "birth_day" field. It's identical to BirthDayEQ.

func BirthDayContains

func BirthDayContains(v string) predicate.User

BirthDayContains applies the Contains predicate on the "birth_day" field.

func BirthDayContainsFold

func BirthDayContainsFold(v string) predicate.User

BirthDayContainsFold applies the ContainsFold predicate on the "birth_day" field.

func BirthDayEQ

func BirthDayEQ(v string) predicate.User

BirthDayEQ applies the EQ predicate on the "birth_day" field.

func BirthDayEqualFold

func BirthDayEqualFold(v string) predicate.User

BirthDayEqualFold applies the EqualFold predicate on the "birth_day" field.

func BirthDayGT

func BirthDayGT(v string) predicate.User

BirthDayGT applies the GT predicate on the "birth_day" field.

func BirthDayGTE

func BirthDayGTE(v string) predicate.User

BirthDayGTE applies the GTE predicate on the "birth_day" field.

func BirthDayHasPrefix

func BirthDayHasPrefix(v string) predicate.User

BirthDayHasPrefix applies the HasPrefix predicate on the "birth_day" field.

func BirthDayHasSuffix

func BirthDayHasSuffix(v string) predicate.User

BirthDayHasSuffix applies the HasSuffix predicate on the "birth_day" field.

func BirthDayIn

func BirthDayIn(vs ...string) predicate.User

BirthDayIn applies the In predicate on the "birth_day" field.

func BirthDayIsNil

func BirthDayIsNil() predicate.User

BirthDayIsNil applies the IsNil predicate on the "birth_day" field.

func BirthDayLT

func BirthDayLT(v string) predicate.User

BirthDayLT applies the LT predicate on the "birth_day" field.

func BirthDayLTE

func BirthDayLTE(v string) predicate.User

BirthDayLTE applies the LTE predicate on the "birth_day" field.

func BirthDayNEQ

func BirthDayNEQ(v string) predicate.User

BirthDayNEQ applies the NEQ predicate on the "birth_day" field.

func BirthDayNotIn

func BirthDayNotIn(vs ...string) predicate.User

BirthDayNotIn applies the NotIn predicate on the "birth_day" field.

func BirthDayNotNil

func BirthDayNotNil() predicate.User

BirthDayNotNil applies the NotNil predicate on the "birth_day" field.

func CityID

func CityID(v string) predicate.User

CityID applies equality check predicate on the "city_id" field. It's identical to CityIDEQ.

func CityIDContains

func CityIDContains(v string) predicate.User

CityIDContains applies the Contains predicate on the "city_id" field.

func CityIDContainsFold

func CityIDContainsFold(v string) predicate.User

CityIDContainsFold applies the ContainsFold predicate on the "city_id" field.

func CityIDEQ

func CityIDEQ(v string) predicate.User

CityIDEQ applies the EQ predicate on the "city_id" field.

func CityIDEqualFold

func CityIDEqualFold(v string) predicate.User

CityIDEqualFold applies the EqualFold predicate on the "city_id" field.

func CityIDGT

func CityIDGT(v string) predicate.User

CityIDGT applies the GT predicate on the "city_id" field.

func CityIDGTE

func CityIDGTE(v string) predicate.User

CityIDGTE applies the GTE predicate on the "city_id" field.

func CityIDHasPrefix

func CityIDHasPrefix(v string) predicate.User

CityIDHasPrefix applies the HasPrefix predicate on the "city_id" field.

func CityIDHasSuffix

func CityIDHasSuffix(v string) predicate.User

CityIDHasSuffix applies the HasSuffix predicate on the "city_id" field.

func CityIDIn

func CityIDIn(vs ...string) predicate.User

CityIDIn applies the In predicate on the "city_id" field.

func CityIDIsNil

func CityIDIsNil() predicate.User

CityIDIsNil applies the IsNil predicate on the "city_id" field.

func CityIDLT

func CityIDLT(v string) predicate.User

CityIDLT applies the LT predicate on the "city_id" field.

func CityIDLTE

func CityIDLTE(v string) predicate.User

CityIDLTE applies the LTE predicate on the "city_id" field.

func CityIDNEQ

func CityIDNEQ(v string) predicate.User

CityIDNEQ applies the NEQ predicate on the "city_id" field.

func CityIDNotIn

func CityIDNotIn(vs ...string) predicate.User

CityIDNotIn applies the NotIn predicate on the "city_id" field.

func CityIDNotNil

func CityIDNotNil() predicate.User

CityIDNotNil applies the NotNil predicate on the "city_id" field.

func CountryCode

func CountryCode(v string) predicate.User

CountryCode applies equality check predicate on the "country_code" field. It's identical to CountryCodeEQ.

func CountryCodeContains

func CountryCodeContains(v string) predicate.User

CountryCodeContains applies the Contains predicate on the "country_code" field.

func CountryCodeContainsFold

func CountryCodeContainsFold(v string) predicate.User

CountryCodeContainsFold applies the ContainsFold predicate on the "country_code" field.

func CountryCodeEQ

func CountryCodeEQ(v string) predicate.User

CountryCodeEQ applies the EQ predicate on the "country_code" field.

func CountryCodeEqualFold

func CountryCodeEqualFold(v string) predicate.User

CountryCodeEqualFold applies the EqualFold predicate on the "country_code" field.

func CountryCodeGT

func CountryCodeGT(v string) predicate.User

CountryCodeGT applies the GT predicate on the "country_code" field.

func CountryCodeGTE

func CountryCodeGTE(v string) predicate.User

CountryCodeGTE applies the GTE predicate on the "country_code" field.

func CountryCodeHasPrefix

func CountryCodeHasPrefix(v string) predicate.User

CountryCodeHasPrefix applies the HasPrefix predicate on the "country_code" field.

func CountryCodeHasSuffix

func CountryCodeHasSuffix(v string) predicate.User

CountryCodeHasSuffix applies the HasSuffix predicate on the "country_code" field.

func CountryCodeIn

func CountryCodeIn(vs ...string) predicate.User

CountryCodeIn applies the In predicate on the "country_code" field.

func CountryCodeIsNil

func CountryCodeIsNil() predicate.User

CountryCodeIsNil applies the IsNil predicate on the "country_code" field.

func CountryCodeLT

func CountryCodeLT(v string) predicate.User

CountryCodeLT applies the LT predicate on the "country_code" field.

func CountryCodeLTE

func CountryCodeLTE(v string) predicate.User

CountryCodeLTE applies the LTE predicate on the "country_code" field.

func CountryCodeNEQ

func CountryCodeNEQ(v string) predicate.User

CountryCodeNEQ applies the NEQ predicate on the "country_code" field.

func CountryCodeNotIn

func CountryCodeNotIn(vs ...string) predicate.User

CountryCodeNotIn applies the NotIn predicate on the "country_code" field.

func CountryCodeNotNil

func CountryCodeNotNil() predicate.User

CountryCodeNotNil applies the NotNil predicate on the "country_code" field.

func CreatedAt

func CreatedAt(v time.Time) predicate.User

CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.

func CreatedAtEQ

func CreatedAtEQ(v time.Time) predicate.User

CreatedAtEQ applies the EQ predicate on the "created_at" field.

func CreatedAtGT

func CreatedAtGT(v time.Time) predicate.User

CreatedAtGT applies the GT predicate on the "created_at" field.

func CreatedAtGTE

func CreatedAtGTE(v time.Time) predicate.User

CreatedAtGTE applies the GTE predicate on the "created_at" field.

func CreatedAtIn

func CreatedAtIn(vs ...time.Time) predicate.User

CreatedAtIn applies the In predicate on the "created_at" field.

func CreatedAtLT

func CreatedAtLT(v time.Time) predicate.User

CreatedAtLT applies the LT predicate on the "created_at" field.

func CreatedAtLTE

func CreatedAtLTE(v time.Time) predicate.User

CreatedAtLTE applies the LTE predicate on the "created_at" field.

func CreatedAtNEQ

func CreatedAtNEQ(v time.Time) predicate.User

CreatedAtNEQ applies the NEQ predicate on the "created_at" field.

func CreatedAtNotIn

func CreatedAtNotIn(vs ...time.Time) predicate.User

CreatedAtNotIn applies the NotIn predicate on the "created_at" field.

func DistrictID

func DistrictID(v string) predicate.User

DistrictID applies equality check predicate on the "district_id" field. It's identical to DistrictIDEQ.

func DistrictIDContains

func DistrictIDContains(v string) predicate.User

DistrictIDContains applies the Contains predicate on the "district_id" field.

func DistrictIDContainsFold

func DistrictIDContainsFold(v string) predicate.User

DistrictIDContainsFold applies the ContainsFold predicate on the "district_id" field.

func DistrictIDEQ

func DistrictIDEQ(v string) predicate.User

DistrictIDEQ applies the EQ predicate on the "district_id" field.

func DistrictIDEqualFold

func DistrictIDEqualFold(v string) predicate.User

DistrictIDEqualFold applies the EqualFold predicate on the "district_id" field.

func DistrictIDGT

func DistrictIDGT(v string) predicate.User

DistrictIDGT applies the GT predicate on the "district_id" field.

func DistrictIDGTE

func DistrictIDGTE(v string) predicate.User

DistrictIDGTE applies the GTE predicate on the "district_id" field.

func DistrictIDHasPrefix

func DistrictIDHasPrefix(v string) predicate.User

DistrictIDHasPrefix applies the HasPrefix predicate on the "district_id" field.

func DistrictIDHasSuffix

func DistrictIDHasSuffix(v string) predicate.User

DistrictIDHasSuffix applies the HasSuffix predicate on the "district_id" field.

func DistrictIDIn

func DistrictIDIn(vs ...string) predicate.User

DistrictIDIn applies the In predicate on the "district_id" field.

func DistrictIDIsNil

func DistrictIDIsNil() predicate.User

DistrictIDIsNil applies the IsNil predicate on the "district_id" field.

func DistrictIDLT

func DistrictIDLT(v string) predicate.User

DistrictIDLT applies the LT predicate on the "district_id" field.

func DistrictIDLTE

func DistrictIDLTE(v string) predicate.User

DistrictIDLTE applies the LTE predicate on the "district_id" field.

func DistrictIDNEQ

func DistrictIDNEQ(v string) predicate.User

DistrictIDNEQ applies the NEQ predicate on the "district_id" field.

func DistrictIDNotIn

func DistrictIDNotIn(vs ...string) predicate.User

DistrictIDNotIn applies the NotIn predicate on the "district_id" field.

func DistrictIDNotNil

func DistrictIDNotNil() predicate.User

DistrictIDNotNil applies the NotNil predicate on the "district_id" field.

func Email

func Email(v string) predicate.User

Email applies equality check predicate on the "email" field. It's identical to EmailEQ.

func EmailContains

func EmailContains(v string) predicate.User

EmailContains applies the Contains predicate on the "email" field.

func EmailContainsFold

func EmailContainsFold(v string) predicate.User

EmailContainsFold applies the ContainsFold predicate on the "email" field.

func EmailEQ

func EmailEQ(v string) predicate.User

EmailEQ applies the EQ predicate on the "email" field.

func EmailEqualFold

func EmailEqualFold(v string) predicate.User

EmailEqualFold applies the EqualFold predicate on the "email" field.

func EmailGT

func EmailGT(v string) predicate.User

EmailGT applies the GT predicate on the "email" field.

func EmailGTE

func EmailGTE(v string) predicate.User

EmailGTE applies the GTE predicate on the "email" field.

func EmailHasPrefix

func EmailHasPrefix(v string) predicate.User

EmailHasPrefix applies the HasPrefix predicate on the "email" field.

func EmailHasSuffix

func EmailHasSuffix(v string) predicate.User

EmailHasSuffix applies the HasSuffix predicate on the "email" field.

func EmailIn

func EmailIn(vs ...string) predicate.User

EmailIn applies the In predicate on the "email" field.

func EmailLT

func EmailLT(v string) predicate.User

EmailLT applies the LT predicate on the "email" field.

func EmailLTE

func EmailLTE(v string) predicate.User

EmailLTE applies the LTE predicate on the "email" field.

func EmailNEQ

func EmailNEQ(v string) predicate.User

EmailNEQ applies the NEQ predicate on the "email" field.

func EmailNotIn

func EmailNotIn(vs ...string) predicate.User

EmailNotIn applies the NotIn predicate on the "email" field.

func FirstName

func FirstName(v string) predicate.User

FirstName applies equality check predicate on the "first_name" field. It's identical to FirstNameEQ.

func FirstNameContains

func FirstNameContains(v string) predicate.User

FirstNameContains applies the Contains predicate on the "first_name" field.

func FirstNameContainsFold

func FirstNameContainsFold(v string) predicate.User

FirstNameContainsFold applies the ContainsFold predicate on the "first_name" field.

func FirstNameEQ

func FirstNameEQ(v string) predicate.User

FirstNameEQ applies the EQ predicate on the "first_name" field.

func FirstNameEqualFold

func FirstNameEqualFold(v string) predicate.User

FirstNameEqualFold applies the EqualFold predicate on the "first_name" field.

func FirstNameGT

func FirstNameGT(v string) predicate.User

FirstNameGT applies the GT predicate on the "first_name" field.

func FirstNameGTE

func FirstNameGTE(v string) predicate.User

FirstNameGTE applies the GTE predicate on the "first_name" field.

func FirstNameHasPrefix

func FirstNameHasPrefix(v string) predicate.User

FirstNameHasPrefix applies the HasPrefix predicate on the "first_name" field.

func FirstNameHasSuffix

func FirstNameHasSuffix(v string) predicate.User

FirstNameHasSuffix applies the HasSuffix predicate on the "first_name" field.

func FirstNameIn

func FirstNameIn(vs ...string) predicate.User

FirstNameIn applies the In predicate on the "first_name" field.

func FirstNameIsNil

func FirstNameIsNil() predicate.User

FirstNameIsNil applies the IsNil predicate on the "first_name" field.

func FirstNameLT

func FirstNameLT(v string) predicate.User

FirstNameLT applies the LT predicate on the "first_name" field.

func FirstNameLTE

func FirstNameLTE(v string) predicate.User

FirstNameLTE applies the LTE predicate on the "first_name" field.

func FirstNameNEQ

func FirstNameNEQ(v string) predicate.User

FirstNameNEQ applies the NEQ predicate on the "first_name" field.

func FirstNameNotIn

func FirstNameNotIn(vs ...string) predicate.User

FirstNameNotIn applies the NotIn predicate on the "first_name" field.

func FirstNameNotNil

func FirstNameNotNil() predicate.User

FirstNameNotNil applies the NotNil predicate on the "first_name" field.

func Gender

func Gender(v int) predicate.User

Gender applies equality check predicate on the "gender" field. It's identical to GenderEQ.

func GenderEQ

func GenderEQ(v int) predicate.User

GenderEQ applies the EQ predicate on the "gender" field.

func GenderGT

func GenderGT(v int) predicate.User

GenderGT applies the GT predicate on the "gender" field.

func GenderGTE

func GenderGTE(v int) predicate.User

GenderGTE applies the GTE predicate on the "gender" field.

func GenderIn

func GenderIn(vs ...int) predicate.User

GenderIn applies the In predicate on the "gender" field.

func GenderIsNil

func GenderIsNil() predicate.User

GenderIsNil applies the IsNil predicate on the "gender" field.

func GenderLT

func GenderLT(v int) predicate.User

GenderLT applies the LT predicate on the "gender" field.

func GenderLTE

func GenderLTE(v int) predicate.User

GenderLTE applies the LTE predicate on the "gender" field.

func GenderNEQ

func GenderNEQ(v int) predicate.User

GenderNEQ applies the NEQ predicate on the "gender" field.

func GenderNotIn

func GenderNotIn(vs ...int) predicate.User

GenderNotIn applies the NotIn predicate on the "gender" field.

func GenderNotNil

func GenderNotNil() predicate.User

GenderNotNil applies the NotNil predicate on the "gender" field.

func HashPassword

func HashPassword(v string) predicate.User

HashPassword applies equality check predicate on the "hash_password" field. It's identical to HashPasswordEQ.

func HashPasswordContains

func HashPasswordContains(v string) predicate.User

HashPasswordContains applies the Contains predicate on the "hash_password" field.

func HashPasswordContainsFold

func HashPasswordContainsFold(v string) predicate.User

HashPasswordContainsFold applies the ContainsFold predicate on the "hash_password" field.

func HashPasswordEQ

func HashPasswordEQ(v string) predicate.User

HashPasswordEQ applies the EQ predicate on the "hash_password" field.

func HashPasswordEqualFold

func HashPasswordEqualFold(v string) predicate.User

HashPasswordEqualFold applies the EqualFold predicate on the "hash_password" field.

func HashPasswordGT

func HashPasswordGT(v string) predicate.User

HashPasswordGT applies the GT predicate on the "hash_password" field.

func HashPasswordGTE

func HashPasswordGTE(v string) predicate.User

HashPasswordGTE applies the GTE predicate on the "hash_password" field.

func HashPasswordHasPrefix

func HashPasswordHasPrefix(v string) predicate.User

HashPasswordHasPrefix applies the HasPrefix predicate on the "hash_password" field.

func HashPasswordHasSuffix

func HashPasswordHasSuffix(v string) predicate.User

HashPasswordHasSuffix applies the HasSuffix predicate on the "hash_password" field.

func HashPasswordIn

func HashPasswordIn(vs ...string) predicate.User

HashPasswordIn applies the In predicate on the "hash_password" field.

func HashPasswordLT

func HashPasswordLT(v string) predicate.User

HashPasswordLT applies the LT predicate on the "hash_password" field.

func HashPasswordLTE

func HashPasswordLTE(v string) predicate.User

HashPasswordLTE applies the LTE predicate on the "hash_password" field.

func HashPasswordNEQ

func HashPasswordNEQ(v string) predicate.User

HashPasswordNEQ applies the NEQ predicate on the "hash_password" field.

func HashPasswordNotIn

func HashPasswordNotIn(vs ...string) predicate.User

HashPasswordNotIn applies the NotIn predicate on the "hash_password" field.

func ID

func ID(id uuid.UUID) predicate.User

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id uuid.UUID) predicate.User

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id uuid.UUID) predicate.User

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id uuid.UUID) predicate.User

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...uuid.UUID) predicate.User

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id uuid.UUID) predicate.User

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id uuid.UUID) predicate.User

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id uuid.UUID) predicate.User

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...uuid.UUID) predicate.User

IDNotIn applies the NotIn predicate on the ID field.

func LastName

func LastName(v string) predicate.User

LastName applies equality check predicate on the "last_name" field. It's identical to LastNameEQ.

func LastNameContains

func LastNameContains(v string) predicate.User

LastNameContains applies the Contains predicate on the "last_name" field.

func LastNameContainsFold

func LastNameContainsFold(v string) predicate.User

LastNameContainsFold applies the ContainsFold predicate on the "last_name" field.

func LastNameEQ

func LastNameEQ(v string) predicate.User

LastNameEQ applies the EQ predicate on the "last_name" field.

func LastNameEqualFold

func LastNameEqualFold(v string) predicate.User

LastNameEqualFold applies the EqualFold predicate on the "last_name" field.

func LastNameGT

func LastNameGT(v string) predicate.User

LastNameGT applies the GT predicate on the "last_name" field.

func LastNameGTE

func LastNameGTE(v string) predicate.User

LastNameGTE applies the GTE predicate on the "last_name" field.

func LastNameHasPrefix

func LastNameHasPrefix(v string) predicate.User

LastNameHasPrefix applies the HasPrefix predicate on the "last_name" field.

func LastNameHasSuffix

func LastNameHasSuffix(v string) predicate.User

LastNameHasSuffix applies the HasSuffix predicate on the "last_name" field.

func LastNameIn

func LastNameIn(vs ...string) predicate.User

LastNameIn applies the In predicate on the "last_name" field.

func LastNameIsNil

func LastNameIsNil() predicate.User

LastNameIsNil applies the IsNil predicate on the "last_name" field.

func LastNameLT

func LastNameLT(v string) predicate.User

LastNameLT applies the LT predicate on the "last_name" field.

func LastNameLTE

func LastNameLTE(v string) predicate.User

LastNameLTE applies the LTE predicate on the "last_name" field.

func LastNameNEQ

func LastNameNEQ(v string) predicate.User

LastNameNEQ applies the NEQ predicate on the "last_name" field.

func LastNameNotIn

func LastNameNotIn(vs ...string) predicate.User

LastNameNotIn applies the NotIn predicate on the "last_name" field.

func LastNameNotNil

func LastNameNotNil() predicate.User

LastNameNotNil applies the NotNil predicate on the "last_name" field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.User) predicate.User

Or groups predicates with the OR operator between them.

func PhoneNumber

func PhoneNumber(v string) predicate.User

PhoneNumber applies equality check predicate on the "phone_number" field. It's identical to PhoneNumberEQ.

func PhoneNumberContains

func PhoneNumberContains(v string) predicate.User

PhoneNumberContains applies the Contains predicate on the "phone_number" field.

func PhoneNumberContainsFold

func PhoneNumberContainsFold(v string) predicate.User

PhoneNumberContainsFold applies the ContainsFold predicate on the "phone_number" field.

func PhoneNumberEQ

func PhoneNumberEQ(v string) predicate.User

PhoneNumberEQ applies the EQ predicate on the "phone_number" field.

func PhoneNumberEqualFold

func PhoneNumberEqualFold(v string) predicate.User

PhoneNumberEqualFold applies the EqualFold predicate on the "phone_number" field.

func PhoneNumberGT

func PhoneNumberGT(v string) predicate.User

PhoneNumberGT applies the GT predicate on the "phone_number" field.

func PhoneNumberGTE

func PhoneNumberGTE(v string) predicate.User

PhoneNumberGTE applies the GTE predicate on the "phone_number" field.

func PhoneNumberHasPrefix

func PhoneNumberHasPrefix(v string) predicate.User

PhoneNumberHasPrefix applies the HasPrefix predicate on the "phone_number" field.

func PhoneNumberHasSuffix

func PhoneNumberHasSuffix(v string) predicate.User

PhoneNumberHasSuffix applies the HasSuffix predicate on the "phone_number" field.

func PhoneNumberIn

func PhoneNumberIn(vs ...string) predicate.User

PhoneNumberIn applies the In predicate on the "phone_number" field.

func PhoneNumberIsNil

func PhoneNumberIsNil() predicate.User

PhoneNumberIsNil applies the IsNil predicate on the "phone_number" field.

func PhoneNumberLT

func PhoneNumberLT(v string) predicate.User

PhoneNumberLT applies the LT predicate on the "phone_number" field.

func PhoneNumberLTE

func PhoneNumberLTE(v string) predicate.User

PhoneNumberLTE applies the LTE predicate on the "phone_number" field.

func PhoneNumberNEQ

func PhoneNumberNEQ(v string) predicate.User

PhoneNumberNEQ applies the NEQ predicate on the "phone_number" field.

func PhoneNumberNotIn

func PhoneNumberNotIn(vs ...string) predicate.User

PhoneNumberNotIn applies the NotIn predicate on the "phone_number" field.

func PhoneNumberNotNil

func PhoneNumberNotNil() predicate.User

PhoneNumberNotNil applies the NotNil predicate on the "phone_number" field.

func Status

func Status(v string) predicate.User

Status applies equality check predicate on the "status" field. It's identical to StatusEQ.

func StatusContains

func StatusContains(v string) predicate.User

StatusContains applies the Contains predicate on the "status" field.

func StatusContainsFold

func StatusContainsFold(v string) predicate.User

StatusContainsFold applies the ContainsFold predicate on the "status" field.

func StatusEQ

func StatusEQ(v string) predicate.User

StatusEQ applies the EQ predicate on the "status" field.

func StatusEqualFold

func StatusEqualFold(v string) predicate.User

StatusEqualFold applies the EqualFold predicate on the "status" field.

func StatusGT

func StatusGT(v string) predicate.User

StatusGT applies the GT predicate on the "status" field.

func StatusGTE

func StatusGTE(v string) predicate.User

StatusGTE applies the GTE predicate on the "status" field.

func StatusHasPrefix

func StatusHasPrefix(v string) predicate.User

StatusHasPrefix applies the HasPrefix predicate on the "status" field.

func StatusHasSuffix

func StatusHasSuffix(v string) predicate.User

StatusHasSuffix applies the HasSuffix predicate on the "status" field.

func StatusIn

func StatusIn(vs ...string) predicate.User

StatusIn applies the In predicate on the "status" field.

func StatusLT

func StatusLT(v string) predicate.User

StatusLT applies the LT predicate on the "status" field.

func StatusLTE

func StatusLTE(v string) predicate.User

StatusLTE applies the LTE predicate on the "status" field.

func StatusNEQ

func StatusNEQ(v string) predicate.User

StatusNEQ applies the NEQ predicate on the "status" field.

func StatusNotIn

func StatusNotIn(vs ...string) predicate.User

StatusNotIn applies the NotIn predicate on the "status" field.

func Street

func Street(v string) predicate.User

Street applies equality check predicate on the "street" field. It's identical to StreetEQ.

func StreetContains

func StreetContains(v string) predicate.User

StreetContains applies the Contains predicate on the "street" field.

func StreetContainsFold

func StreetContainsFold(v string) predicate.User

StreetContainsFold applies the ContainsFold predicate on the "street" field.

func StreetEQ

func StreetEQ(v string) predicate.User

StreetEQ applies the EQ predicate on the "street" field.

func StreetEqualFold

func StreetEqualFold(v string) predicate.User

StreetEqualFold applies the EqualFold predicate on the "street" field.

func StreetGT

func StreetGT(v string) predicate.User

StreetGT applies the GT predicate on the "street" field.

func StreetGTE

func StreetGTE(v string) predicate.User

StreetGTE applies the GTE predicate on the "street" field.

func StreetHasPrefix

func StreetHasPrefix(v string) predicate.User

StreetHasPrefix applies the HasPrefix predicate on the "street" field.

func StreetHasSuffix

func StreetHasSuffix(v string) predicate.User

StreetHasSuffix applies the HasSuffix predicate on the "street" field.

func StreetIn

func StreetIn(vs ...string) predicate.User

StreetIn applies the In predicate on the "street" field.

func StreetIsNil

func StreetIsNil() predicate.User

StreetIsNil applies the IsNil predicate on the "street" field.

func StreetLT

func StreetLT(v string) predicate.User

StreetLT applies the LT predicate on the "street" field.

func StreetLTE

func StreetLTE(v string) predicate.User

StreetLTE applies the LTE predicate on the "street" field.

func StreetNEQ

func StreetNEQ(v string) predicate.User

StreetNEQ applies the NEQ predicate on the "street" field.

func StreetNotIn

func StreetNotIn(vs ...string) predicate.User

StreetNotIn applies the NotIn predicate on the "street" field.

func StreetNotNil

func StreetNotNil() predicate.User

StreetNotNil applies the NotNil predicate on the "street" field.

func UpdatedAt

func UpdatedAt(v time.Time) predicate.User

UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.

func UpdatedAtEQ

func UpdatedAtEQ(v time.Time) predicate.User

UpdatedAtEQ applies the EQ predicate on the "updated_at" field.

func UpdatedAtGT

func UpdatedAtGT(v time.Time) predicate.User

UpdatedAtGT applies the GT predicate on the "updated_at" field.

func UpdatedAtGTE

func UpdatedAtGTE(v time.Time) predicate.User

UpdatedAtGTE applies the GTE predicate on the "updated_at" field.

func UpdatedAtIn

func UpdatedAtIn(vs ...time.Time) predicate.User

UpdatedAtIn applies the In predicate on the "updated_at" field.

func UpdatedAtLT

func UpdatedAtLT(v time.Time) predicate.User

UpdatedAtLT applies the LT predicate on the "updated_at" field.

func UpdatedAtLTE

func UpdatedAtLTE(v time.Time) predicate.User

UpdatedAtLTE applies the LTE predicate on the "updated_at" field.

func UpdatedAtNEQ

func UpdatedAtNEQ(v time.Time) predicate.User

UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.

func UpdatedAtNotIn

func UpdatedAtNotIn(vs ...time.Time) predicate.User

UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.

func Username

func Username(v string) predicate.User

Username applies equality check predicate on the "username" field. It's identical to UsernameEQ.

func UsernameContains

func UsernameContains(v string) predicate.User

UsernameContains applies the Contains predicate on the "username" field.

func UsernameContainsFold

func UsernameContainsFold(v string) predicate.User

UsernameContainsFold applies the ContainsFold predicate on the "username" field.

func UsernameEQ

func UsernameEQ(v string) predicate.User

UsernameEQ applies the EQ predicate on the "username" field.

func UsernameEqualFold

func UsernameEqualFold(v string) predicate.User

UsernameEqualFold applies the EqualFold predicate on the "username" field.

func UsernameGT

func UsernameGT(v string) predicate.User

UsernameGT applies the GT predicate on the "username" field.

func UsernameGTE

func UsernameGTE(v string) predicate.User

UsernameGTE applies the GTE predicate on the "username" field.

func UsernameHasPrefix

func UsernameHasPrefix(v string) predicate.User

UsernameHasPrefix applies the HasPrefix predicate on the "username" field.

func UsernameHasSuffix

func UsernameHasSuffix(v string) predicate.User

UsernameHasSuffix applies the HasSuffix predicate on the "username" field.

func UsernameIn

func UsernameIn(vs ...string) predicate.User

UsernameIn applies the In predicate on the "username" field.

func UsernameLT

func UsernameLT(v string) predicate.User

UsernameLT applies the LT predicate on the "username" field.

func UsernameLTE

func UsernameLTE(v string) predicate.User

UsernameLTE applies the LTE predicate on the "username" field.

func UsernameNEQ

func UsernameNEQ(v string) predicate.User

UsernameNEQ applies the NEQ predicate on the "username" field.

func UsernameNotIn

func UsernameNotIn(vs ...string) predicate.User

UsernameNotIn applies the NotIn predicate on the "username" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

func Verified

func Verified(v bool) predicate.User

Verified applies equality check predicate on the "verified" field. It's identical to VerifiedEQ.

func VerifiedEQ

func VerifiedEQ(v bool) predicate.User

VerifiedEQ applies the EQ predicate on the "verified" field.

func VerifiedNEQ

func VerifiedNEQ(v bool) predicate.User

VerifiedNEQ applies the NEQ predicate on the "verified" field.

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the User queries.

func ByAddress

func ByAddress(opts ...sql.OrderTermOption) OrderOption

ByAddress orders the results by the address field.

func ByAvatar

func ByAvatar(opts ...sql.OrderTermOption) OrderOption

ByAvatar orders the results by the avatar field.

func ByBirthDay

func ByBirthDay(opts ...sql.OrderTermOption) OrderOption

ByBirthDay orders the results by the birth_day field.

func ByCityID

func ByCityID(opts ...sql.OrderTermOption) OrderOption

ByCityID orders the results by the city_id field.

func ByCountryCode

func ByCountryCode(opts ...sql.OrderTermOption) OrderOption

ByCountryCode orders the results by the country_code field.

func ByCreatedAt

func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption

ByCreatedAt orders the results by the created_at field.

func ByDistrictID

func ByDistrictID(opts ...sql.OrderTermOption) OrderOption

ByDistrictID orders the results by the district_id field.

func ByEmail

func ByEmail(opts ...sql.OrderTermOption) OrderOption

ByEmail orders the results by the email field.

func ByFirstName

func ByFirstName(opts ...sql.OrderTermOption) OrderOption

ByFirstName orders the results by the first_name field.

func ByGender

func ByGender(opts ...sql.OrderTermOption) OrderOption

ByGender orders the results by the gender field.

func ByHashPassword

func ByHashPassword(opts ...sql.OrderTermOption) OrderOption

ByHashPassword orders the results by the hash_password field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByLastName

func ByLastName(opts ...sql.OrderTermOption) OrderOption

ByLastName orders the results by the last_name field.

func ByPhoneNumber

func ByPhoneNumber(opts ...sql.OrderTermOption) OrderOption

ByPhoneNumber orders the results by the phone_number field.

func ByStatus

func ByStatus(opts ...sql.OrderTermOption) OrderOption

ByStatus orders the results by the status field.

func ByStreet

func ByStreet(opts ...sql.OrderTermOption) OrderOption

ByStreet orders the results by the street field.

func ByUpdatedAt

func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption

ByUpdatedAt orders the results by the updated_at field.

func ByUsername

func ByUsername(opts ...sql.OrderTermOption) OrderOption

ByUsername orders the results by the username field.

func ByVerified

func ByVerified(opts ...sql.OrderTermOption) OrderOption

ByVerified orders the results by the verified field.

Jump to