Documentation
¶
Index ¶
- Constants
- Variables
- func Address(v string) predicate.User
- func AddressContains(v string) predicate.User
- func AddressContainsFold(v string) predicate.User
- func AddressEQ(v string) predicate.User
- func AddressEqualFold(v string) predicate.User
- func AddressGT(v string) predicate.User
- func AddressGTE(v string) predicate.User
- func AddressHasPrefix(v string) predicate.User
- func AddressHasSuffix(v string) predicate.User
- func AddressIn(vs ...string) predicate.User
- func AddressIsNil() predicate.User
- func AddressLT(v string) predicate.User
- func AddressLTE(v string) predicate.User
- func AddressNEQ(v string) predicate.User
- func AddressNotIn(vs ...string) predicate.User
- func AddressNotNil() predicate.User
- func And(predicates ...predicate.User) predicate.User
- func Avatar(v string) predicate.User
- func AvatarContains(v string) predicate.User
- func AvatarContainsFold(v string) predicate.User
- func AvatarEQ(v string) predicate.User
- func AvatarEqualFold(v string) predicate.User
- func AvatarGT(v string) predicate.User
- func AvatarGTE(v string) predicate.User
- func AvatarHasPrefix(v string) predicate.User
- func AvatarHasSuffix(v string) predicate.User
- func AvatarIn(vs ...string) predicate.User
- func AvatarIsNil() predicate.User
- func AvatarLT(v string) predicate.User
- func AvatarLTE(v string) predicate.User
- func AvatarNEQ(v string) predicate.User
- func AvatarNotIn(vs ...string) predicate.User
- func AvatarNotNil() predicate.User
- func BirthDay(v string) predicate.User
- func BirthDayContains(v string) predicate.User
- func BirthDayContainsFold(v string) predicate.User
- func BirthDayEQ(v string) predicate.User
- func BirthDayEqualFold(v string) predicate.User
- func BirthDayGT(v string) predicate.User
- func BirthDayGTE(v string) predicate.User
- func BirthDayHasPrefix(v string) predicate.User
- func BirthDayHasSuffix(v string) predicate.User
- func BirthDayIn(vs ...string) predicate.User
- func BirthDayIsNil() predicate.User
- func BirthDayLT(v string) predicate.User
- func BirthDayLTE(v string) predicate.User
- func BirthDayNEQ(v string) predicate.User
- func BirthDayNotIn(vs ...string) predicate.User
- func BirthDayNotNil() predicate.User
- func CityID(v string) predicate.User
- func CityIDContains(v string) predicate.User
- func CityIDContainsFold(v string) predicate.User
- func CityIDEQ(v string) predicate.User
- func CityIDEqualFold(v string) predicate.User
- func CityIDGT(v string) predicate.User
- func CityIDGTE(v string) predicate.User
- func CityIDHasPrefix(v string) predicate.User
- func CityIDHasSuffix(v string) predicate.User
- func CityIDIn(vs ...string) predicate.User
- func CityIDIsNil() predicate.User
- func CityIDLT(v string) predicate.User
- func CityIDLTE(v string) predicate.User
- func CityIDNEQ(v string) predicate.User
- func CityIDNotIn(vs ...string) predicate.User
- func CityIDNotNil() predicate.User
- func CountryCode(v string) predicate.User
- func CountryCodeContains(v string) predicate.User
- func CountryCodeContainsFold(v string) predicate.User
- func CountryCodeEQ(v string) predicate.User
- func CountryCodeEqualFold(v string) predicate.User
- func CountryCodeGT(v string) predicate.User
- func CountryCodeGTE(v string) predicate.User
- func CountryCodeHasPrefix(v string) predicate.User
- func CountryCodeHasSuffix(v string) predicate.User
- func CountryCodeIn(vs ...string) predicate.User
- func CountryCodeIsNil() predicate.User
- func CountryCodeLT(v string) predicate.User
- func CountryCodeLTE(v string) predicate.User
- func CountryCodeNEQ(v string) predicate.User
- func CountryCodeNotIn(vs ...string) predicate.User
- func CountryCodeNotNil() predicate.User
- func CreatedAt(v time.Time) predicate.User
- func CreatedAtEQ(v time.Time) predicate.User
- func CreatedAtGT(v time.Time) predicate.User
- func CreatedAtGTE(v time.Time) predicate.User
- func CreatedAtIn(vs ...time.Time) predicate.User
- func CreatedAtLT(v time.Time) predicate.User
- func CreatedAtLTE(v time.Time) predicate.User
- func CreatedAtNEQ(v time.Time) predicate.User
- func CreatedAtNotIn(vs ...time.Time) predicate.User
- func DistrictID(v string) predicate.User
- func DistrictIDContains(v string) predicate.User
- func DistrictIDContainsFold(v string) predicate.User
- func DistrictIDEQ(v string) predicate.User
- func DistrictIDEqualFold(v string) predicate.User
- func DistrictIDGT(v string) predicate.User
- func DistrictIDGTE(v string) predicate.User
- func DistrictIDHasPrefix(v string) predicate.User
- func DistrictIDHasSuffix(v string) predicate.User
- func DistrictIDIn(vs ...string) predicate.User
- func DistrictIDIsNil() predicate.User
- func DistrictIDLT(v string) predicate.User
- func DistrictIDLTE(v string) predicate.User
- func DistrictIDNEQ(v string) predicate.User
- func DistrictIDNotIn(vs ...string) predicate.User
- func DistrictIDNotNil() predicate.User
- func Email(v string) predicate.User
- func EmailContains(v string) predicate.User
- func EmailContainsFold(v string) predicate.User
- func EmailEQ(v string) predicate.User
- func EmailEqualFold(v string) predicate.User
- func EmailGT(v string) predicate.User
- func EmailGTE(v string) predicate.User
- func EmailHasPrefix(v string) predicate.User
- func EmailHasSuffix(v string) predicate.User
- func EmailIn(vs ...string) predicate.User
- func EmailLT(v string) predicate.User
- func EmailLTE(v string) predicate.User
- func EmailNEQ(v string) predicate.User
- func EmailNotIn(vs ...string) predicate.User
- func FirstName(v string) predicate.User
- func FirstNameContains(v string) predicate.User
- func FirstNameContainsFold(v string) predicate.User
- func FirstNameEQ(v string) predicate.User
- func FirstNameEqualFold(v string) predicate.User
- func FirstNameGT(v string) predicate.User
- func FirstNameGTE(v string) predicate.User
- func FirstNameHasPrefix(v string) predicate.User
- func FirstNameHasSuffix(v string) predicate.User
- func FirstNameIn(vs ...string) predicate.User
- func FirstNameIsNil() predicate.User
- func FirstNameLT(v string) predicate.User
- func FirstNameLTE(v string) predicate.User
- func FirstNameNEQ(v string) predicate.User
- func FirstNameNotIn(vs ...string) predicate.User
- func FirstNameNotNil() predicate.User
- func Gender(v int) predicate.User
- func GenderEQ(v int) predicate.User
- func GenderGT(v int) predicate.User
- func GenderGTE(v int) predicate.User
- func GenderIn(vs ...int) predicate.User
- func GenderIsNil() predicate.User
- func GenderLT(v int) predicate.User
- func GenderLTE(v int) predicate.User
- func GenderNEQ(v int) predicate.User
- func GenderNotIn(vs ...int) predicate.User
- func GenderNotNil() predicate.User
- func HashPassword(v string) predicate.User
- func HashPasswordContains(v string) predicate.User
- func HashPasswordContainsFold(v string) predicate.User
- func HashPasswordEQ(v string) predicate.User
- func HashPasswordEqualFold(v string) predicate.User
- func HashPasswordGT(v string) predicate.User
- func HashPasswordGTE(v string) predicate.User
- func HashPasswordHasPrefix(v string) predicate.User
- func HashPasswordHasSuffix(v string) predicate.User
- func HashPasswordIn(vs ...string) predicate.User
- func HashPasswordLT(v string) predicate.User
- func HashPasswordLTE(v string) predicate.User
- func HashPasswordNEQ(v string) predicate.User
- func HashPasswordNotIn(vs ...string) predicate.User
- func ID(id uuid.UUID) predicate.User
- func IDEQ(id uuid.UUID) predicate.User
- func IDGT(id uuid.UUID) predicate.User
- func IDGTE(id uuid.UUID) predicate.User
- func IDIn(ids ...uuid.UUID) predicate.User
- func IDLT(id uuid.UUID) predicate.User
- func IDLTE(id uuid.UUID) predicate.User
- func IDNEQ(id uuid.UUID) predicate.User
- func IDNotIn(ids ...uuid.UUID) predicate.User
- func LastName(v string) predicate.User
- func LastNameContains(v string) predicate.User
- func LastNameContainsFold(v string) predicate.User
- func LastNameEQ(v string) predicate.User
- func LastNameEqualFold(v string) predicate.User
- func LastNameGT(v string) predicate.User
- func LastNameGTE(v string) predicate.User
- func LastNameHasPrefix(v string) predicate.User
- func LastNameHasSuffix(v string) predicate.User
- func LastNameIn(vs ...string) predicate.User
- func LastNameIsNil() predicate.User
- func LastNameLT(v string) predicate.User
- func LastNameLTE(v string) predicate.User
- func LastNameNEQ(v string) predicate.User
- func LastNameNotIn(vs ...string) predicate.User
- func LastNameNotNil() predicate.User
- func Not(p predicate.User) predicate.User
- func Or(predicates ...predicate.User) predicate.User
- func PhoneNumber(v string) predicate.User
- func PhoneNumberContains(v string) predicate.User
- func PhoneNumberContainsFold(v string) predicate.User
- func PhoneNumberEQ(v string) predicate.User
- func PhoneNumberEqualFold(v string) predicate.User
- func PhoneNumberGT(v string) predicate.User
- func PhoneNumberGTE(v string) predicate.User
- func PhoneNumberHasPrefix(v string) predicate.User
- func PhoneNumberHasSuffix(v string) predicate.User
- func PhoneNumberIn(vs ...string) predicate.User
- func PhoneNumberIsNil() predicate.User
- func PhoneNumberLT(v string) predicate.User
- func PhoneNumberLTE(v string) predicate.User
- func PhoneNumberNEQ(v string) predicate.User
- func PhoneNumberNotIn(vs ...string) predicate.User
- func PhoneNumberNotNil() predicate.User
- func Status(v string) predicate.User
- func StatusContains(v string) predicate.User
- func StatusContainsFold(v string) predicate.User
- func StatusEQ(v string) predicate.User
- func StatusEqualFold(v string) predicate.User
- func StatusGT(v string) predicate.User
- func StatusGTE(v string) predicate.User
- func StatusHasPrefix(v string) predicate.User
- func StatusHasSuffix(v string) predicate.User
- func StatusIn(vs ...string) predicate.User
- func StatusLT(v string) predicate.User
- func StatusLTE(v string) predicate.User
- func StatusNEQ(v string) predicate.User
- func StatusNotIn(vs ...string) predicate.User
- func Street(v string) predicate.User
- func StreetContains(v string) predicate.User
- func StreetContainsFold(v string) predicate.User
- func StreetEQ(v string) predicate.User
- func StreetEqualFold(v string) predicate.User
- func StreetGT(v string) predicate.User
- func StreetGTE(v string) predicate.User
- func StreetHasPrefix(v string) predicate.User
- func StreetHasSuffix(v string) predicate.User
- func StreetIn(vs ...string) predicate.User
- func StreetIsNil() predicate.User
- func StreetLT(v string) predicate.User
- func StreetLTE(v string) predicate.User
- func StreetNEQ(v string) predicate.User
- func StreetNotIn(vs ...string) predicate.User
- func StreetNotNil() predicate.User
- func UpdatedAt(v time.Time) predicate.User
- func UpdatedAtEQ(v time.Time) predicate.User
- func UpdatedAtGT(v time.Time) predicate.User
- func UpdatedAtGTE(v time.Time) predicate.User
- func UpdatedAtIn(vs ...time.Time) predicate.User
- func UpdatedAtLT(v time.Time) predicate.User
- func UpdatedAtLTE(v time.Time) predicate.User
- func UpdatedAtNEQ(v time.Time) predicate.User
- func UpdatedAtNotIn(vs ...time.Time) predicate.User
- func Username(v string) predicate.User
- func UsernameContains(v string) predicate.User
- func UsernameContainsFold(v string) predicate.User
- func UsernameEQ(v string) predicate.User
- func UsernameEqualFold(v string) predicate.User
- func UsernameGT(v string) predicate.User
- func UsernameGTE(v string) predicate.User
- func UsernameHasPrefix(v string) predicate.User
- func UsernameHasSuffix(v string) predicate.User
- func UsernameIn(vs ...string) predicate.User
- func UsernameLT(v string) predicate.User
- func UsernameLTE(v string) predicate.User
- func UsernameNEQ(v string) predicate.User
- func UsernameNotIn(vs ...string) predicate.User
- func ValidColumn(column string) bool
- func Verified(v bool) predicate.User
- func VerifiedEQ(v bool) predicate.User
- func VerifiedNEQ(v bool) predicate.User
- type OrderOption
- func ByAddress(opts ...sql.OrderTermOption) OrderOption
- func ByAvatar(opts ...sql.OrderTermOption) OrderOption
- func ByBirthDay(opts ...sql.OrderTermOption) OrderOption
- func ByCityID(opts ...sql.OrderTermOption) OrderOption
- func ByCountryCode(opts ...sql.OrderTermOption) OrderOption
- func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByDistrictID(opts ...sql.OrderTermOption) OrderOption
- func ByEmail(opts ...sql.OrderTermOption) OrderOption
- func ByFirstName(opts ...sql.OrderTermOption) OrderOption
- func ByGender(opts ...sql.OrderTermOption) OrderOption
- func ByHashPassword(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByLastName(opts ...sql.OrderTermOption) OrderOption
- func ByPhoneNumber(opts ...sql.OrderTermOption) OrderOption
- func ByStatus(opts ...sql.OrderTermOption) OrderOption
- func ByStreet(opts ...sql.OrderTermOption) OrderOption
- func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByUsername(opts ...sql.OrderTermOption) OrderOption
- func ByVerified(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the user type in the database. Label = "user" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldUsername holds the string denoting the username field in the database. FieldUsername = "username" // FieldEmail holds the string denoting the email field in the database. FieldEmail = "email" // FieldAvatar holds the string denoting the avatar field in the database. FieldAvatar = "avatar" // FieldBirthDay holds the string denoting the birth_day field in the database. FieldBirthDay = "birth_day" // FieldFirstName holds the string denoting the first_name field in the database. FieldFirstName = "first_name" // FieldLastName holds the string denoting the last_name field in the database. FieldLastName = "last_name" // FieldPhoneNumber holds the string denoting the phone_number field in the database. FieldPhoneNumber = "phone_number" // FieldGender holds the string denoting the gender field in the database. FieldGender = "gender" // FieldStatus holds the string denoting the status field in the database. FieldStatus = "status" // FieldAddress holds the string denoting the address field in the database. FieldAddress = "address" // FieldStreet holds the string denoting the street field in the database. FieldStreet = "street" // FieldDistrictID holds the string denoting the district_id field in the database. FieldDistrictID = "district_id" // FieldCityID holds the string denoting the city_id field in the database. FieldCityID = "city_id" // FieldCountryCode holds the string denoting the country_code field in the database. FieldCountryCode = "country_code" // FieldHashPassword holds the string denoting the hash_password field in the database. FieldHashPassword = "hash_password" // FieldVerified holds the string denoting the verified field in the database. FieldVerified = "verified" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // FieldUpdatedAt holds the string denoting the updated_at field in the database. FieldUpdatedAt = "updated_at" // Table holds the table name of the user in the database. Table = "users" )
Variables ¶
var ( // UsernameValidator is a validator for the "username" field. It is called by the builders before save. UsernameValidator func(string) error // EmailValidator is a validator for the "email" field. It is called by the builders before save. EmailValidator func(string) error // HashPasswordValidator is a validator for the "hash_password" field. It is called by the builders before save. HashPasswordValidator func(string) error // DefaultVerified holds the default value on creation for the "verified" field. DefaultVerified bool // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time // DefaultUpdatedAt holds the default value on creation for the "updated_at" field. DefaultUpdatedAt func() time.Time // UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field. UpdateDefaultUpdatedAt func() time.Time // DefaultID holds the default value on creation for the "id" field. DefaultID func() uuid.UUID )
var Columns = []string{ FieldID, FieldUsername, FieldEmail, FieldAvatar, FieldBirthDay, FieldFirstName, FieldLastName, FieldPhoneNumber, FieldGender, FieldStatus, FieldAddress, FieldStreet, FieldDistrictID, FieldCityID, FieldCountryCode, FieldHashPassword, FieldVerified, FieldCreatedAt, FieldUpdatedAt, }
Columns holds all SQL columns for user fields.
Functions ¶
func Address ¶
Address applies equality check predicate on the "address" field. It's identical to AddressEQ.
func AddressContains ¶
AddressContains applies the Contains predicate on the "address" field.
func AddressContainsFold ¶
AddressContainsFold applies the ContainsFold predicate on the "address" field.
func AddressEqualFold ¶
AddressEqualFold applies the EqualFold predicate on the "address" field.
func AddressGTE ¶
AddressGTE applies the GTE predicate on the "address" field.
func AddressHasPrefix ¶
AddressHasPrefix applies the HasPrefix predicate on the "address" field.
func AddressHasSuffix ¶
AddressHasSuffix applies the HasSuffix predicate on the "address" field.
func AddressIsNil ¶
AddressIsNil applies the IsNil predicate on the "address" field.
func AddressLTE ¶
AddressLTE applies the LTE predicate on the "address" field.
func AddressNEQ ¶
AddressNEQ applies the NEQ predicate on the "address" field.
func AddressNotIn ¶
AddressNotIn applies the NotIn predicate on the "address" field.
func AddressNotNil ¶
AddressNotNil applies the NotNil predicate on the "address" field.
func Avatar ¶
Avatar applies equality check predicate on the "avatar" field. It's identical to AvatarEQ.
func AvatarContains ¶
AvatarContains applies the Contains predicate on the "avatar" field.
func AvatarContainsFold ¶
AvatarContainsFold applies the ContainsFold predicate on the "avatar" field.
func AvatarEqualFold ¶
AvatarEqualFold applies the EqualFold predicate on the "avatar" field.
func AvatarHasPrefix ¶
AvatarHasPrefix applies the HasPrefix predicate on the "avatar" field.
func AvatarHasSuffix ¶
AvatarHasSuffix applies the HasSuffix predicate on the "avatar" field.
func AvatarIsNil ¶
AvatarIsNil applies the IsNil predicate on the "avatar" field.
func AvatarNotIn ¶
AvatarNotIn applies the NotIn predicate on the "avatar" field.
func AvatarNotNil ¶
AvatarNotNil applies the NotNil predicate on the "avatar" field.
func BirthDay ¶
BirthDay applies equality check predicate on the "birth_day" field. It's identical to BirthDayEQ.
func BirthDayContains ¶
BirthDayContains applies the Contains predicate on the "birth_day" field.
func BirthDayContainsFold ¶
BirthDayContainsFold applies the ContainsFold predicate on the "birth_day" field.
func BirthDayEQ ¶
BirthDayEQ applies the EQ predicate on the "birth_day" field.
func BirthDayEqualFold ¶
BirthDayEqualFold applies the EqualFold predicate on the "birth_day" field.
func BirthDayGT ¶
BirthDayGT applies the GT predicate on the "birth_day" field.
func BirthDayGTE ¶
BirthDayGTE applies the GTE predicate on the "birth_day" field.
func BirthDayHasPrefix ¶
BirthDayHasPrefix applies the HasPrefix predicate on the "birth_day" field.
func BirthDayHasSuffix ¶
BirthDayHasSuffix applies the HasSuffix predicate on the "birth_day" field.
func BirthDayIn ¶
BirthDayIn applies the In predicate on the "birth_day" field.
func BirthDayIsNil ¶
BirthDayIsNil applies the IsNil predicate on the "birth_day" field.
func BirthDayLT ¶
BirthDayLT applies the LT predicate on the "birth_day" field.
func BirthDayLTE ¶
BirthDayLTE applies the LTE predicate on the "birth_day" field.
func BirthDayNEQ ¶
BirthDayNEQ applies the NEQ predicate on the "birth_day" field.
func BirthDayNotIn ¶
BirthDayNotIn applies the NotIn predicate on the "birth_day" field.
func BirthDayNotNil ¶
BirthDayNotNil applies the NotNil predicate on the "birth_day" field.
func CityID ¶
CityID applies equality check predicate on the "city_id" field. It's identical to CityIDEQ.
func CityIDContains ¶
CityIDContains applies the Contains predicate on the "city_id" field.
func CityIDContainsFold ¶
CityIDContainsFold applies the ContainsFold predicate on the "city_id" field.
func CityIDEqualFold ¶
CityIDEqualFold applies the EqualFold predicate on the "city_id" field.
func CityIDHasPrefix ¶
CityIDHasPrefix applies the HasPrefix predicate on the "city_id" field.
func CityIDHasSuffix ¶
CityIDHasSuffix applies the HasSuffix predicate on the "city_id" field.
func CityIDIsNil ¶
CityIDIsNil applies the IsNil predicate on the "city_id" field.
func CityIDNotIn ¶
CityIDNotIn applies the NotIn predicate on the "city_id" field.
func CityIDNotNil ¶
CityIDNotNil applies the NotNil predicate on the "city_id" field.
func CountryCode ¶
CountryCode applies equality check predicate on the "country_code" field. It's identical to CountryCodeEQ.
func CountryCodeContains ¶
CountryCodeContains applies the Contains predicate on the "country_code" field.
func CountryCodeContainsFold ¶
CountryCodeContainsFold applies the ContainsFold predicate on the "country_code" field.
func CountryCodeEQ ¶
CountryCodeEQ applies the EQ predicate on the "country_code" field.
func CountryCodeEqualFold ¶
CountryCodeEqualFold applies the EqualFold predicate on the "country_code" field.
func CountryCodeGT ¶
CountryCodeGT applies the GT predicate on the "country_code" field.
func CountryCodeGTE ¶
CountryCodeGTE applies the GTE predicate on the "country_code" field.
func CountryCodeHasPrefix ¶
CountryCodeHasPrefix applies the HasPrefix predicate on the "country_code" field.
func CountryCodeHasSuffix ¶
CountryCodeHasSuffix applies the HasSuffix predicate on the "country_code" field.
func CountryCodeIn ¶
CountryCodeIn applies the In predicate on the "country_code" field.
func CountryCodeIsNil ¶
CountryCodeIsNil applies the IsNil predicate on the "country_code" field.
func CountryCodeLT ¶
CountryCodeLT applies the LT predicate on the "country_code" field.
func CountryCodeLTE ¶
CountryCodeLTE applies the LTE predicate on the "country_code" field.
func CountryCodeNEQ ¶
CountryCodeNEQ applies the NEQ predicate on the "country_code" field.
func CountryCodeNotIn ¶
CountryCodeNotIn applies the NotIn predicate on the "country_code" field.
func CountryCodeNotNil ¶
CountryCodeNotNil applies the NotNil predicate on the "country_code" field.
func CreatedAt ¶
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtLT ¶
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func DistrictID ¶
DistrictID applies equality check predicate on the "district_id" field. It's identical to DistrictIDEQ.
func DistrictIDContains ¶
DistrictIDContains applies the Contains predicate on the "district_id" field.
func DistrictIDContainsFold ¶
DistrictIDContainsFold applies the ContainsFold predicate on the "district_id" field.
func DistrictIDEQ ¶
DistrictIDEQ applies the EQ predicate on the "district_id" field.
func DistrictIDEqualFold ¶
DistrictIDEqualFold applies the EqualFold predicate on the "district_id" field.
func DistrictIDGT ¶
DistrictIDGT applies the GT predicate on the "district_id" field.
func DistrictIDGTE ¶
DistrictIDGTE applies the GTE predicate on the "district_id" field.
func DistrictIDHasPrefix ¶
DistrictIDHasPrefix applies the HasPrefix predicate on the "district_id" field.
func DistrictIDHasSuffix ¶
DistrictIDHasSuffix applies the HasSuffix predicate on the "district_id" field.
func DistrictIDIn ¶
DistrictIDIn applies the In predicate on the "district_id" field.
func DistrictIDIsNil ¶
DistrictIDIsNil applies the IsNil predicate on the "district_id" field.
func DistrictIDLT ¶
DistrictIDLT applies the LT predicate on the "district_id" field.
func DistrictIDLTE ¶
DistrictIDLTE applies the LTE predicate on the "district_id" field.
func DistrictIDNEQ ¶
DistrictIDNEQ applies the NEQ predicate on the "district_id" field.
func DistrictIDNotIn ¶
DistrictIDNotIn applies the NotIn predicate on the "district_id" field.
func DistrictIDNotNil ¶
DistrictIDNotNil applies the NotNil predicate on the "district_id" field.
func Email ¶
Email applies equality check predicate on the "email" field. It's identical to EmailEQ.
func EmailContains ¶
EmailContains applies the Contains predicate on the "email" field.
func EmailContainsFold ¶
EmailContainsFold applies the ContainsFold predicate on the "email" field.
func EmailEqualFold ¶
EmailEqualFold applies the EqualFold predicate on the "email" field.
func EmailHasPrefix ¶
EmailHasPrefix applies the HasPrefix predicate on the "email" field.
func EmailHasSuffix ¶
EmailHasSuffix applies the HasSuffix predicate on the "email" field.
func EmailNotIn ¶
EmailNotIn applies the NotIn predicate on the "email" field.
func FirstName ¶
FirstName applies equality check predicate on the "first_name" field. It's identical to FirstNameEQ.
func FirstNameContains ¶
FirstNameContains applies the Contains predicate on the "first_name" field.
func FirstNameContainsFold ¶
FirstNameContainsFold applies the ContainsFold predicate on the "first_name" field.
func FirstNameEQ ¶
FirstNameEQ applies the EQ predicate on the "first_name" field.
func FirstNameEqualFold ¶
FirstNameEqualFold applies the EqualFold predicate on the "first_name" field.
func FirstNameGT ¶
FirstNameGT applies the GT predicate on the "first_name" field.
func FirstNameGTE ¶
FirstNameGTE applies the GTE predicate on the "first_name" field.
func FirstNameHasPrefix ¶
FirstNameHasPrefix applies the HasPrefix predicate on the "first_name" field.
func FirstNameHasSuffix ¶
FirstNameHasSuffix applies the HasSuffix predicate on the "first_name" field.
func FirstNameIn ¶
FirstNameIn applies the In predicate on the "first_name" field.
func FirstNameIsNil ¶
FirstNameIsNil applies the IsNil predicate on the "first_name" field.
func FirstNameLT ¶
FirstNameLT applies the LT predicate on the "first_name" field.
func FirstNameLTE ¶
FirstNameLTE applies the LTE predicate on the "first_name" field.
func FirstNameNEQ ¶
FirstNameNEQ applies the NEQ predicate on the "first_name" field.
func FirstNameNotIn ¶
FirstNameNotIn applies the NotIn predicate on the "first_name" field.
func FirstNameNotNil ¶
FirstNameNotNil applies the NotNil predicate on the "first_name" field.
func Gender ¶
Gender applies equality check predicate on the "gender" field. It's identical to GenderEQ.
func GenderIsNil ¶
GenderIsNil applies the IsNil predicate on the "gender" field.
func GenderNotIn ¶
GenderNotIn applies the NotIn predicate on the "gender" field.
func GenderNotNil ¶
GenderNotNil applies the NotNil predicate on the "gender" field.
func HashPassword ¶
HashPassword applies equality check predicate on the "hash_password" field. It's identical to HashPasswordEQ.
func HashPasswordContains ¶
HashPasswordContains applies the Contains predicate on the "hash_password" field.
func HashPasswordContainsFold ¶
HashPasswordContainsFold applies the ContainsFold predicate on the "hash_password" field.
func HashPasswordEQ ¶
HashPasswordEQ applies the EQ predicate on the "hash_password" field.
func HashPasswordEqualFold ¶
HashPasswordEqualFold applies the EqualFold predicate on the "hash_password" field.
func HashPasswordGT ¶
HashPasswordGT applies the GT predicate on the "hash_password" field.
func HashPasswordGTE ¶
HashPasswordGTE applies the GTE predicate on the "hash_password" field.
func HashPasswordHasPrefix ¶
HashPasswordHasPrefix applies the HasPrefix predicate on the "hash_password" field.
func HashPasswordHasSuffix ¶
HashPasswordHasSuffix applies the HasSuffix predicate on the "hash_password" field.
func HashPasswordIn ¶
HashPasswordIn applies the In predicate on the "hash_password" field.
func HashPasswordLT ¶
HashPasswordLT applies the LT predicate on the "hash_password" field.
func HashPasswordLTE ¶
HashPasswordLTE applies the LTE predicate on the "hash_password" field.
func HashPasswordNEQ ¶
HashPasswordNEQ applies the NEQ predicate on the "hash_password" field.
func HashPasswordNotIn ¶
HashPasswordNotIn applies the NotIn predicate on the "hash_password" field.
func LastName ¶
LastName applies equality check predicate on the "last_name" field. It's identical to LastNameEQ.
func LastNameContains ¶
LastNameContains applies the Contains predicate on the "last_name" field.
func LastNameContainsFold ¶
LastNameContainsFold applies the ContainsFold predicate on the "last_name" field.
func LastNameEQ ¶
LastNameEQ applies the EQ predicate on the "last_name" field.
func LastNameEqualFold ¶
LastNameEqualFold applies the EqualFold predicate on the "last_name" field.
func LastNameGT ¶
LastNameGT applies the GT predicate on the "last_name" field.
func LastNameGTE ¶
LastNameGTE applies the GTE predicate on the "last_name" field.
func LastNameHasPrefix ¶
LastNameHasPrefix applies the HasPrefix predicate on the "last_name" field.
func LastNameHasSuffix ¶
LastNameHasSuffix applies the HasSuffix predicate on the "last_name" field.
func LastNameIn ¶
LastNameIn applies the In predicate on the "last_name" field.
func LastNameIsNil ¶
LastNameIsNil applies the IsNil predicate on the "last_name" field.
func LastNameLT ¶
LastNameLT applies the LT predicate on the "last_name" field.
func LastNameLTE ¶
LastNameLTE applies the LTE predicate on the "last_name" field.
func LastNameNEQ ¶
LastNameNEQ applies the NEQ predicate on the "last_name" field.
func LastNameNotIn ¶
LastNameNotIn applies the NotIn predicate on the "last_name" field.
func LastNameNotNil ¶
LastNameNotNil applies the NotNil predicate on the "last_name" field.
func PhoneNumber ¶
PhoneNumber applies equality check predicate on the "phone_number" field. It's identical to PhoneNumberEQ.
func PhoneNumberContains ¶
PhoneNumberContains applies the Contains predicate on the "phone_number" field.
func PhoneNumberContainsFold ¶
PhoneNumberContainsFold applies the ContainsFold predicate on the "phone_number" field.
func PhoneNumberEQ ¶
PhoneNumberEQ applies the EQ predicate on the "phone_number" field.
func PhoneNumberEqualFold ¶
PhoneNumberEqualFold applies the EqualFold predicate on the "phone_number" field.
func PhoneNumberGT ¶
PhoneNumberGT applies the GT predicate on the "phone_number" field.
func PhoneNumberGTE ¶
PhoneNumberGTE applies the GTE predicate on the "phone_number" field.
func PhoneNumberHasPrefix ¶
PhoneNumberHasPrefix applies the HasPrefix predicate on the "phone_number" field.
func PhoneNumberHasSuffix ¶
PhoneNumberHasSuffix applies the HasSuffix predicate on the "phone_number" field.
func PhoneNumberIn ¶
PhoneNumberIn applies the In predicate on the "phone_number" field.
func PhoneNumberIsNil ¶
PhoneNumberIsNil applies the IsNil predicate on the "phone_number" field.
func PhoneNumberLT ¶
PhoneNumberLT applies the LT predicate on the "phone_number" field.
func PhoneNumberLTE ¶
PhoneNumberLTE applies the LTE predicate on the "phone_number" field.
func PhoneNumberNEQ ¶
PhoneNumberNEQ applies the NEQ predicate on the "phone_number" field.
func PhoneNumberNotIn ¶
PhoneNumberNotIn applies the NotIn predicate on the "phone_number" field.
func PhoneNumberNotNil ¶
PhoneNumberNotNil applies the NotNil predicate on the "phone_number" field.
func Status ¶
Status applies equality check predicate on the "status" field. It's identical to StatusEQ.
func StatusContains ¶
StatusContains applies the Contains predicate on the "status" field.
func StatusContainsFold ¶
StatusContainsFold applies the ContainsFold predicate on the "status" field.
func StatusEqualFold ¶
StatusEqualFold applies the EqualFold predicate on the "status" field.
func StatusHasPrefix ¶
StatusHasPrefix applies the HasPrefix predicate on the "status" field.
func StatusHasSuffix ¶
StatusHasSuffix applies the HasSuffix predicate on the "status" field.
func StatusNotIn ¶
StatusNotIn applies the NotIn predicate on the "status" field.
func Street ¶
Street applies equality check predicate on the "street" field. It's identical to StreetEQ.
func StreetContains ¶
StreetContains applies the Contains predicate on the "street" field.
func StreetContainsFold ¶
StreetContainsFold applies the ContainsFold predicate on the "street" field.
func StreetEqualFold ¶
StreetEqualFold applies the EqualFold predicate on the "street" field.
func StreetHasPrefix ¶
StreetHasPrefix applies the HasPrefix predicate on the "street" field.
func StreetHasSuffix ¶
StreetHasSuffix applies the HasSuffix predicate on the "street" field.
func StreetIsNil ¶
StreetIsNil applies the IsNil predicate on the "street" field.
func StreetNotIn ¶
StreetNotIn applies the NotIn predicate on the "street" field.
func StreetNotNil ¶
StreetNotNil applies the NotNil predicate on the "street" field.
func UpdatedAt ¶
UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.
func UpdatedAtEQ ¶
UpdatedAtEQ applies the EQ predicate on the "updated_at" field.
func UpdatedAtGT ¶
UpdatedAtGT applies the GT predicate on the "updated_at" field.
func UpdatedAtGTE ¶
UpdatedAtGTE applies the GTE predicate on the "updated_at" field.
func UpdatedAtIn ¶
UpdatedAtIn applies the In predicate on the "updated_at" field.
func UpdatedAtLT ¶
UpdatedAtLT applies the LT predicate on the "updated_at" field.
func UpdatedAtLTE ¶
UpdatedAtLTE applies the LTE predicate on the "updated_at" field.
func UpdatedAtNEQ ¶
UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.
func UpdatedAtNotIn ¶
UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.
func Username ¶
Username applies equality check predicate on the "username" field. It's identical to UsernameEQ.
func UsernameContains ¶
UsernameContains applies the Contains predicate on the "username" field.
func UsernameContainsFold ¶
UsernameContainsFold applies the ContainsFold predicate on the "username" field.
func UsernameEQ ¶
UsernameEQ applies the EQ predicate on the "username" field.
func UsernameEqualFold ¶
UsernameEqualFold applies the EqualFold predicate on the "username" field.
func UsernameGT ¶
UsernameGT applies the GT predicate on the "username" field.
func UsernameGTE ¶
UsernameGTE applies the GTE predicate on the "username" field.
func UsernameHasPrefix ¶
UsernameHasPrefix applies the HasPrefix predicate on the "username" field.
func UsernameHasSuffix ¶
UsernameHasSuffix applies the HasSuffix predicate on the "username" field.
func UsernameIn ¶
UsernameIn applies the In predicate on the "username" field.
func UsernameLT ¶
UsernameLT applies the LT predicate on the "username" field.
func UsernameLTE ¶
UsernameLTE applies the LTE predicate on the "username" field.
func UsernameNEQ ¶
UsernameNEQ applies the NEQ predicate on the "username" field.
func UsernameNotIn ¶
UsernameNotIn applies the NotIn predicate on the "username" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
func Verified ¶
Verified applies equality check predicate on the "verified" field. It's identical to VerifiedEQ.
func VerifiedEQ ¶
VerifiedEQ applies the EQ predicate on the "verified" field.
func VerifiedNEQ ¶
VerifiedNEQ applies the NEQ predicate on the "verified" field.
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the User queries.
func ByAddress ¶
func ByAddress(opts ...sql.OrderTermOption) OrderOption
ByAddress orders the results by the address field.
func ByAvatar ¶
func ByAvatar(opts ...sql.OrderTermOption) OrderOption
ByAvatar orders the results by the avatar field.
func ByBirthDay ¶
func ByBirthDay(opts ...sql.OrderTermOption) OrderOption
ByBirthDay orders the results by the birth_day field.
func ByCityID ¶
func ByCityID(opts ...sql.OrderTermOption) OrderOption
ByCityID orders the results by the city_id field.
func ByCountryCode ¶
func ByCountryCode(opts ...sql.OrderTermOption) OrderOption
ByCountryCode orders the results by the country_code field.
func ByCreatedAt ¶
func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
ByCreatedAt orders the results by the created_at field.
func ByDistrictID ¶
func ByDistrictID(opts ...sql.OrderTermOption) OrderOption
ByDistrictID orders the results by the district_id field.
func ByEmail ¶
func ByEmail(opts ...sql.OrderTermOption) OrderOption
ByEmail orders the results by the email field.
func ByFirstName ¶
func ByFirstName(opts ...sql.OrderTermOption) OrderOption
ByFirstName orders the results by the first_name field.
func ByGender ¶
func ByGender(opts ...sql.OrderTermOption) OrderOption
ByGender orders the results by the gender field.
func ByHashPassword ¶
func ByHashPassword(opts ...sql.OrderTermOption) OrderOption
ByHashPassword orders the results by the hash_password field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByLastName ¶
func ByLastName(opts ...sql.OrderTermOption) OrderOption
ByLastName orders the results by the last_name field.
func ByPhoneNumber ¶
func ByPhoneNumber(opts ...sql.OrderTermOption) OrderOption
ByPhoneNumber orders the results by the phone_number field.
func ByStatus ¶
func ByStatus(opts ...sql.OrderTermOption) OrderOption
ByStatus orders the results by the status field.
func ByStreet ¶
func ByStreet(opts ...sql.OrderTermOption) OrderOption
ByStreet orders the results by the street field.
func ByUpdatedAt ¶
func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
ByUpdatedAt orders the results by the updated_at field.
func ByUsername ¶
func ByUsername(opts ...sql.OrderTermOption) OrderOption
ByUsername orders the results by the username field.
func ByVerified ¶
func ByVerified(opts ...sql.OrderTermOption) OrderOption
ByVerified orders the results by the verified field.